Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4083)

Unified Diff: base/test/thread_test_helper.h

Issue 2924813002: Make ThreadTestHelper sequence-friendly. (Closed)
Patch Set: fix typo Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/test/thread_test_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/test/thread_test_helper.h
diff --git a/base/test/thread_test_helper.h b/base/test/thread_test_helper.h
index 829a6197eab88edce2bb53d9bf804481537ce1db..935e7efc6b95f4acfc077b6b470abba694e11348 100644
--- a/base/test/thread_test_helper.h
+++ b/base/test/thread_test_helper.h
@@ -8,21 +8,21 @@
#include "base/compiler_specific.h"
#include "base/macros.h"
#include "base/memory/ref_counted.h"
-#include "base/single_thread_task_runner.h"
+#include "base/sequenced_task_runner.h"
#include "base/synchronization/waitable_event.h"
namespace base {
// Helper class that executes code on a given thread while blocking on the
// invoking thread. To use, derive from this class and overwrite RunTest. An
// alternative use of this class is to use it directly. It will then block
// until all pending tasks on a given thread have been executed.
class ThreadTestHelper : public RefCountedThreadSafe<ThreadTestHelper> {
public:
- explicit ThreadTestHelper(
- scoped_refptr<SingleThreadTaskRunner> target_thread);
+ explicit ThreadTestHelper(scoped_refptr<SequencedTaskRunner> target_sequence);
- // True if RunTest() was successfully executed on the target thread.
+ // True if RunTest() was successfully executed on the target sequence.
bool Run() WARN_UNUSED_RESULT;
virtual void RunTest();
@@ -36,10 +36,10 @@ class ThreadTestHelper : public RefCountedThreadSafe<ThreadTestHelper> {
void set_test_result(bool test_result) { test_result_ = test_result; }
private:
- void RunInThread();
+ void RunOnSequence();
bool test_result_;
- scoped_refptr<SingleThreadTaskRunner> target_thread_;
+ scoped_refptr<SequencedTaskRunner> target_sequence_;
WaitableEvent done_event_;
DISALLOW_COPY_AND_ASSIGN(ThreadTestHelper);
« no previous file with comments | « no previous file | base/test/thread_test_helper.cc » ('j') | no next file with comments »
@@ -8,21 +8,21 @@
#include "base/synchronization/waitable_event.h"
namespace base {
-// Helper class that executes code on a given thread while blocking on the
-// invoking thread. To use, derive from this class and overwrite RunTest. An
-// alternative use of this class is to use it directly. It will then block
-// until all pending tasks on a given thread have been executed.
+// Helper class that executes code on a given target sequence/thread while
+// blocking on the invoking sequence/thread. To use, derive from this class and
+// overwrite RunTest. An alternative use of this class is to use it directly. It
+// will then block until all pending tasks on a given sequence/thread have been
+// executed.
class ThreadTestHelper : public RefCountedThreadSafe<ThreadTestHelper> {
public:

Powered by Google App Engine
This is Rietveld 408576698